package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Jul 11, 2026
License: MIT
Opens a new window with license information.
Imports: 22
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package ui provides the local HTTP foundation for the repolens UI.
Run starts the local UI server and blocks until ctx is canceled.
type Options struct {
Addr string
}
Options configures the local UI HTTP server.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.